<?
/*
 * Plugin Name: Simple Quotes
 * Plugin URI: http://www.jasonernst.com/projects/quotes/
 * Description: Creates a custom post type for quotes which will show up in the administrative interface within wordpress. The quotes are then return randomly in an associative array using the function 'quote_random()'. Extremely simple plugin takes only a quote and the quote author. Note: The author icon is taken from the famfamfam icon pack (http://www.famfamfam.com/)
 * Version: 1.0 
 * Author: Jason B. Ernst
 * Author URI: http://www.jasonernst.com/
 * License: GPL2
 */

/*  Copyright 2011  Jason Ernst  (email : jernst@uoguelph.ca)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

add_action('init', 'quote_init'); 
add_action('save_post', 'quote_save');
register_activation_hook( __FILE__, 'quote_flush_rewrite' );
register_deactivation_hook( __FILE__, 'quote_flush_rewrite' );

/*
 * Creates the new "quote" post type and registers it in wordpress
 */ 
function quote_init()
{
	$labels = array(
		'name' => _x('Quotes', 'post type general name'),
		'singular_name' => _x('Quote', 'post type singular name'),
		'add_new' => _x('Add New', 'quote'),
		'add_new_item' => __('Add New Quote'),
		'edit_item' => __('Edit Quote'),
		'new_item' => __('New Quote'),
		'view_item' => __('View Quote'),
		'search_items' => __('Search Quotes'),
		'not_found' =>  __('No quotes found'),
		'not_found_in_trash' => __('No quotes found in Trash'), 
		'parent_item_colon' => '',
		'menu_name' => 'Quotes'
	);
	
	$args = array(
		'labels' => $labels,
		'public' => false,
		'publicly_queryable' => false,
		'show_ui' => true, 
		'show_in_menu' => true, 
		'query_var' => true,
		'rewrite' => true,
		'capability_type' => 'post',
		'register_meta_box_cb' => 'quote_addfields',
		'has_archive' => true, 
		'hierarchical' => false,
		'menu_position' => null,
		'supports' => array('title'),
	); 
	
	register_post_type('quote', $args);
}
 
/*
 * Force a refresh of the rewrite rules
 */
function quote_flush_rewrite()
{
	//flush re-write rules to ensure we don't get 404s
	global $wp_rewrite;
    $wp_rewrite->flush_rules();
}

/*
 * Adds the author field using meta boxes
 */
function quote_addfields()
{
	add_meta_box('quote-author-meta','Quote Author','quote_author_meta','quote','normal','high');
	do_meta_boxes('quote-author-meta','normal',null);
}

/*
 * Adds the html to the admin page for the quote author
 */
function quote_author_meta()
{
	//used to get to the plugin folder
	$base = WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__));
	global $post;
	$quote_author = get_post_meta($post->ID, 'quote_author', true);
	//create a nonce for security
	echo '<input type="hidden" name="quote_noncename" id="quote_noncename" value="' . wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	?>
		<div class="inside">
			<div class="form-field">
				<label for="quote_author"><img src="<?=$base?>/author.png" alt="Quote Author"/> Quote Author: </label>
				<input type="text" name="quote_author" tabindex="3" style="width: 100%;" value="<?=$quote_author?>"/>
				<p>The quote author is the original author of the quote, and does not have to be a blog author.</p>
			</div> <!-- /form-field -->
		</div> <!-- /inside -->
	<?
}

/*
 * Called on a post save, used to save the quote author using metadata
 */
function quote_save($post_id)
{	
	if ( !wp_verify_nonce( $_POST['quote_noncename'], plugin_basename(__FILE__) ))
		return $post_id;
	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
		return $post_id;
			
	// Check permissions
	if ( !current_user_can( 'edit_posts', $post_id ) )
		return $post_id;
	
	$quote_author = $_POST['quote_author'];
	update_post_meta($post_id, 'quote_author', $quote_author);
	return $post_id;
}

/*
 * Returns a random quote using an associative array
 * quote["content"] is the quote itself
 * quote["author"] is the author
 */
function quote_random()
{
	query_posts('orderby=rand&post_type=quote');
	if(have_posts())
	{
		the_post();
		global $post;	
		$quote["content"] = the_title("", "", false);
		$quote["author"] = get_post_meta($post->ID, 'quote_author', true );
		wp_reset_query();
		return $quote;
	}
}
 ?>
